package MappingCfg;

public class cmuFlag {
	static boolean		exit_add_panel;
	static boolean		exit_modify_panel;
	static boolean		exit_copy_panel;
	static boolean		exit_device_panel;
	static boolean		exit_profile_panel;
	
	public static void init()
	{
		exit_add_panel = false;
		exit_modify_panel = false;
		exit_copy_panel = false;
		exit_device_panel = false;
		exit_profile_panel = false;
	}
	
	public static void set_exit_add_panel()
	{
		exit_add_panel = true;		
	}
	public static void clear_exit_add_panel()
	{
		exit_add_panel = false;		
	}
	public static boolean is_exit_add_panel_select()
	{
		if(exit_add_panel == true )
			return true;
		else
			return false;
	}
	
	public static void set_exit_modify_panel()
	{
		exit_modify_panel = true;		
	}
	public static void clear_exit_modify_panel()
	{
		exit_modify_panel = false;		
	}
	public static boolean is_exit_modify_panel_select()
	{
		if(exit_modify_panel == true )
			return true;
		else
			return false;
	}
	
	public static void set_exit_copy_panel()
	{
		exit_copy_panel = true;		
	}
	public static void clear_exit_copy_panel()
	{
		exit_copy_panel = false;		
	}
	public static boolean is_exit_copy_panel_select()
	{
		if(exit_copy_panel == true )
			return true;
		else
			return false;
	}

	public static void set_exit_device_panel()
	{
		exit_device_panel = true;		
	}
	public static void clear_exit_device_panel()
	{
		exit_device_panel = false;		
	}
	public static boolean is_exit_device_panel_select()
	{
		if(exit_device_panel == true )
			return true;
		else
			return false;
	}

	public static void set_exit_profile_panel()
	{
		exit_profile_panel = true;		
	}
	public static void clear_exit_profile_panel()
	{
		exit_profile_panel = false;		
	}
	public static boolean is_exit_profile_panel_select()
	{
		if(exit_profile_panel == true )
			return true;
		else
			return false;
	}
}
